==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/vi-VN/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Người dùng này có thể đăng nhập',
    'activated_disabled_help_text' => 'Bạn không thể sửa tình trạng kích hoạt của tài khoản quản trị.',
    'assets_user'       => 'Tài sản đã được cấp phát đến :name',
    'bulk_update_warn'	=> 'Bạn sắp chỉnh sửa các thuộc tính của: user_count users. Xin lưu ý rằng bạn không thể thay đổi thuộc tính người dùng của mình bằng cách sử dụng biểu mẫu này và phải thực hiện chỉnh sửa cho người dùng riêng của mình.',
    'bulk_update_help'	=> 'Biểu mẫu này cho phép bạn cập nhật nhiều người dùng cùng một lúc. Chỉ điền vào các trường mà bạn cần thay đổi. Bất kỳ trường nào để trống sẽ không thay đổi.',
    'current_assets'    => 'Tài sản hiện được kiểm tra cho người dùng này',
    'clone'             => 'Nhân đôi người dùng',
    'contact_user'      => 'Liên hệ :name',
    'edit'              => 'Sửa người dùng',
    'filetype_info'     => 'Cho phép loại tập tin are png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'Lịch sử cấp phát của :name',
    'info'				=> 'Thông tin',
    'restore_user'		=> 'Nhấp vào đây để khôi phục chúng.',
    'last_login'        => 'Lần đăng nhập trước',
    'ldap_config_text'  => 'Bạn có thể tìm thấy cài đặt cấu hình LDAP Quản trị> Cài đặt. Địa điểm đã chọn (tùy chọn) sẽ được đặt cho tất cả người dùng được nhập.',
    'print_assigned'    => 'In tất cả tài sản đã cấp phát',
    'email_assigned'    => 'Danh sách email của tất cả được chỉ định',
    'user_notified'     => 'Người dùng đã được gửi qua email danh sách các thiết bị hiện được chỉ định của họ.',
    'auto_assign_label' => 'Bao gồm người dùng này khi giấy phép đủ điều kiện tự động chỉ định',
    'auto_assign_help'  => 'Bỏ qua người dùng này trong chế độ tự động chỉ định giấy phép',
    'software_user'     => 'Phần mềm đã được checkout đến :name',
    'send_email_help'   => 'Bạn phải cung cấp địa chỉ email của người dùng để gửi chứng thực. Gửi mail chứng thực chỉ có hiệu lực đối với người dùng tạo ra. Mật khẩu được mã hóa một chiều và không thể lấy lại một khi đã lưu.',
    'view_user'         => 'Xem người dùng :name',
    'usercsv'           => 'Tập tin CSV',
    'two_factor_admin_optin_help' => 'Cài đặt quản trị hiện tại của bạn cho phép thực thi có chọn lọc xác thực hai yếu tố.',
    'two_factor_enrolled' => 'Đã đăng ký thiết bị 2FA ',
    'two_factor_active'   => '2FA đang hoạt động ',
    'user_deactivated'  => 'Người dùng không thể đăng nhập',
    'user_activated'  => 'Người dùng có thể đăng nhập',
    'activation_status_warning' => 'Không thể đổi trạng thái kích hoạt',
    'group_memberships_helpblock' => 'Chỉ có quyền superadmins mới sửa được nhóm này.',
    'superadmin_permission_warning' => 'Chỉ quyền superadmins mới cấp quyền người dùng truy cập.',
    'admin_permission_warning' => 'Chỉ có quyền admins trở lên mới có thể cấp quyền truy cập cho người dùng.',
    'remove_group_memberships' => 'Xóa thành viên nhóm',
    'warning_deletion_information' => 'Bạn sắp kiểm tra TẤT CẢ các thiết bị từ :count người dùng được liệt kê bên dưới. Tên quản trị viên cấp cao được đánh dấu màu đỏ.',
    'update_user_assets_status' => 'Cập nhật tất cả tài sản của những người dùng này vào trạng thái này',
    'checkin_user_properties' => 'Kiểm tra tất cả các thuộc tính được liên kết với những người dùng này',
    'remote_label'   => 'Đây là người dùng từ xa',
    'remote'   => 'Từ xa',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'Đây không phải là người dùng từ xa',
    'vip_label' => 'Người dùng VIP',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Tạo người dùng',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Tiếp theo: Lưu người dùng',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/vi-VN/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Người dùng này có thể đăng nhập',
    'activated_disabled_help_text' => 'Bạn không thể sửa tình trạng kích hoạt của tài khoản quản trị.',
    'assets_user'       => 'Tài sản đã được cấp phát đến :name',
    'bulk_update_warn'	=> 'Bạn sắp chỉnh sửa các thuộc tính của: user_count users. Xin lưu ý rằng bạn không thể thay đổi thuộc tính người dùng của mình bằng cách sử dụng biểu mẫu này và phải thực hiện chỉnh sửa cho người dùng riêng của mình.',
    'bulk_update_help'	=> 'Biểu mẫu này cho phép bạn cập nhật nhiều người dùng cùng một lúc. Chỉ điền vào các trường mà bạn cần thay đổi. Bất kỳ trường nào để trống sẽ không thay đổi.',
    'current_assets'    => 'Tài sản hiện được kiểm tra cho người dùng này',
    'clone'             => 'Nhân đôi người dùng',
    'contact_user'      => 'Liên hệ :name',
    'edit'              => 'Sửa người dùng',
    'filetype_info'     => 'Cho phép loại tập tin are png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'Lịch sử cấp phát của :name',
    'info'				=> 'Thông tin',
    'restore_user'		=> 'Nhấp vào đây để khôi phục chúng.',
    'last_login'        => 'Lần đăng nhập trước',
    'ldap_config_text'  => 'Bạn có thể tìm thấy cài đặt cấu hình LDAP Quản trị> Cài đặt. Địa điểm đã chọn (tùy chọn) sẽ được đặt cho tất cả người dùng được nhập.',
    'print_assigned'    => 'In tất cả tài sản đã cấp phát',
    'email_assigned'    => 'Danh sách email của tất cả được chỉ định',
    'user_notified'     => 'Người dùng đã được gửi qua email danh sách các thiết bị hiện được chỉ định của họ.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Bao gồm người dùng này khi giấy phép đủ điều kiện tự động chỉ định',
    'auto_assign_help'  => 'Bỏ qua người dùng này trong chế độ tự động chỉ định giấy phép',
    'software_user'     => 'Phần mềm đã được checkout đến :name',
    'send_email_help'   => 'Bạn phải cung cấp địa chỉ email của người dùng để gửi chứng thực. Gửi mail chứng thực chỉ có hiệu lực đối với người dùng tạo ra. Mật khẩu được mã hóa một chiều và không thể lấy lại một khi đã lưu.',
    'view_user'         => 'Xem người dùng :name',
    'usercsv'           => 'Tập tin CSV',
    'two_factor_admin_optin_help' => 'Cài đặt quản trị hiện tại của bạn cho phép thực thi có chọn lọc xác thực hai yếu tố.',
    'two_factor_enrolled' => 'Đã đăng ký thiết bị 2FA ',
    'two_factor_active'   => '2FA đang hoạt động ',
    'user_deactivated'  => 'Người dùng không thể đăng nhập',
    'user_activated'  => 'Người dùng có thể đăng nhập',
    'activation_status_warning' => 'Không thể đổi trạng thái kích hoạt',
    'group_memberships_helpblock' => 'Chỉ có quyền superadmins mới sửa được nhóm này.',
    'superadmin_permission_warning' => 'Chỉ quyền superadmins mới cấp quyền người dùng truy cập.',
    'admin_permission_warning' => 'Chỉ có quyền admins trở lên mới có thể cấp quyền truy cập cho người dùng.',
    'remove_group_memberships' => 'Xóa thành viên nhóm',
    'warning_deletion_information' => 'Bạn sắp kiểm tra TẤT CẢ các thiết bị từ :count người dùng được liệt kê bên dưới. Tên quản trị viên cấp cao được đánh dấu màu đỏ.',
    'update_user_assets_status' => 'Cập nhật tất cả tài sản của những người dùng này vào trạng thái này',
    'checkin_user_properties' => 'Kiểm tra tất cả các thuộc tính được liên kết với những người dùng này',
    'remote_label'   => 'Đây là người dùng từ xa',
    'remote'   => 'Từ xa',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'Đây không phải là người dùng từ xa',
    'vip_label' => 'Người dùng VIP',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Tạo người dùng',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Tiếp theo: Lưu người dùng',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];
